@@ -7,7 +7,7 @@ use Class::C3;
 use Carp::Clan qw/^DBIx::Class/;
 use UNIVERSAL::require;
 
-our $VERSION = '0.04999_04';
+our $VERSION = '0.04999_05';
 
 =head1 NAME
 
@@ -45,7 +45,7 @@ sub new {
         croak "Failed to require $subclass: $@";
     }
     elsif(!$@) {
-        bless $self, "DBIx::Class::Schema::Loader::DBI::${driver}";
+        bless $self, $subclass unless $self->isa($subclass);
     }
 
     # Set up the default quoting character and name seperators
